@@ -14,6 +14,7 @@ import traceback
 import urllib
 
 import manifestparser
+import mozfile
 import mozinfo
 import mozinstall
 import mozmill
@@ -170,6 +171,9 @@ class TestRun(object):
     def download_addon(self, url, target_path):
         """ Download the XPI file. """
         try:
+            if not os.path.exists(target_path):
+                os.makedirs(target_path)
+
             filename = url.split('?')[0].rstrip('/').rsplit('/', 1)[-1]
             target_path = os.path.join(target_path, filename)
 
@@ -219,7 +223,7 @@ class TestRun(object):
             if os.path.isdir(self.binary):
                 self._folder = self.binary
             else:
-                if sys.platform == "darwin":
+                if mozinfo.isMac:
                     # Ensure that self._folder is the app bundle on OS X
                     p = re.compile('.*\.app/')
                     self._folder = p.search(self.binary).group()
@@ -239,7 +243,7 @@ class TestRun(object):
             try:
                 # Remove downloaded add-on
                 print "*** Removing downloaded add-on '%s'." % path
-                os.remove(path)
+                mozfile.remove(path)
             except:
                 print "*** Failed to remove downloaded add-on '%s'." % path
 
@@ -298,7 +302,7 @@ class TestRun(object):
             self.results = self._mozmill.finish()
 
             print "*** Removing profile: %s" % profile_path
-            shutil.rmtree(profile_path)
+            mozfile.remove(profile_path)
 
         # Whenever a test fails it has to be marked, so we quit with the correct exit code
         self.last_failed_tests = self.last_failed_tests or self.results.fails
@@ -410,21 +414,14 @@ class AddonsTestRun(TestRun):
 
         filename = None
 
-        # Get the platform the script is running on
-        if sys.platform in ("cygwin", "win32"):
-            platform = "win"
-        elif sys.platform in ("darwin"):
-            platform = "mac"
-        elif sys.platform in ("linux2", "sunos5"):
-            platform = "linux"
-        else:
-            platform = None
-
         try:
             filename = os.path.join(self.repository.path, self._addon_path, "addon.ini")
             config = ConfigParser.RawConfigParser()
             config.read(filename)
 
+            # Get the platform to download platform specific add-ons
+            platform = 'linux' if mozinfo.os in ['bsd', 'unix'] else mozinfo.os
+
             return config.get("download", platform)
         except Exception, e:
             raise errors.NotFoundException('Could not read URL settings', filename)
@@ -457,7 +454,8 @@ class AddonsTestRun(TestRun):
                     continue
 
                 # Download the add-on
-                self.target_addon = self.download_addon(url, tempfile.gettempdir())
+                self.target_addon = self.download_addon(url,
+                                                        os.path.join(self.workspace, 'addons'))
 
                 self.manifest_path = os.path.join(self._addon_path,
                                                   'tests', 'manifest.ini')
@@ -472,10 +470,8 @@ class AddonsTestRun(TestRun):
                 if self.target_addon:
                     self.addon_list.remove(self.target_addon)
                     try:
-                        # Remove downloaded add-on
-                        if os.path.exists(self.target_addon):
-                            print "*** Removing target add-on '%s'." % self.target_addon
-                            os.remove(self.target_addon)
+                        print "*** Removing target add-on '%s'." % self.target_addon
+                        mozfile.remove(self.target_addon)
                     except:
                         print "*** Failed to remove target add-on '%s'." % self.target_addon
 
@@ -657,7 +653,7 @@ class UpdateTestRun(TestRun):
             self._backup_folder = os.path.join(self.workspace, 'binary_backup')
 
             print "*** Creating backup of binary: %s" % self._backup_folder
-            shutil.rmtree(self._backup_folder, True)
+            mozfile.remove(self._backup_folder)
             shutil.copytree(self._folder, self._backup_folder)
 
     def prepare_channel(self):
@@ -678,7 +674,7 @@ class UpdateTestRun(TestRun):
         print "*** Removing binary at '%s'" % self._folder
         while True:
             try:
-                shutil.rmtree(self._folder)
+                mozfile.remove(self._folder)
                 break
             except Exception, e:
                 print str(e)
@@ -723,7 +719,7 @@ class UpdateTestRun(TestRun):
             try:
                 path = self._mozmill.persisted["updateStagingPath"]
                 print "*** Removing updates staging folder: %s" % path
-                shutil.rmtree(path)
+                mozfile.remove(path)
             except Exception, e:
                 print "*** Failed to remove the update staging folder: " + str(e)
                 self.exception_type, self.exception, self.tb = sys.exc_info()
